@@ -1,17 +1,17 @@
 /*-
  * SPDX-License-Identifier: BSD-2-Clause
- * 
+ *
  * Copyright (c) 2020 NKI/AVL, Netherlands Cancer Institute
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
- * 
+ *
  * 1. Redistributions of source code must retain the above copyright notice, this
  *    list of conditions and the following disclaimer
  * 2. Redistributions in binary form must reproduce the above copyright notice,
  *    this list of conditions and the following disclaimer in the documentation
  *    and/or other materials provided with the distribution.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -24,7 +24,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-/* 
+/*
    Created by: Maarten L. Hekkelman
    Date: dinsdag 22 mei, 2018
 */
@@ -35,27 +35,33 @@
 
 #include "cif++/Structure.hpp"
 
+#include "cif++/BondMap.hpp"
+#include "pdb-redo/Compound.hpp"
 #include "pdb-redo/MapMaker.hpp"
-#include "pdb-redo/BondMap.hpp"
 #include "pdb-redo/Restraints.hpp"
 
 // --------------------------------------------------------------------
 
+namespace pdb_redo
+{
+
 class AtomLocationProvider
 {
   public:
-	AtomLocationProvider(const AtomLocationProvider&) = delete;
-	AtomLocationProvider& operator=(const AtomLocationProvider&) = delete;
+	AtomLocationProvider(const AtomLocationProvider &) = delete;
+	AtomLocationProvider &operator=(const AtomLocationProvider &) = delete;
 
-	AtomLocationProvider(std::vector<mmcif::Atom>& atoms)
-		: mAtoms(atoms) {}
+	AtomLocationProvider(std::vector<mmcif::Atom> &atoms)
+		: mAtoms(atoms)
+	{
+	}
 	virtual ~AtomLocationProvider() {}
-	
+
 	virtual mmcif::DPoint operator[](AtomRef atomID) const;
 	virtual std::string atom(AtomRef atomID) const;
 
   protected:
-	std::vector<mmcif::Atom>& mAtoms;
+	std::vector<mmcif::Atom> &mAtoms;
 };
 
 // --------------------------------------------------------------------
@@ -63,14 +69,14 @@ class AtomLocationProvider
 class DFCollector
 {
   public:
-	DFCollector(const DFCollector&) = delete;
-	DFCollector& operator=(const DFCollector&) = delete;
+	DFCollector(const DFCollector &) = delete;
+	DFCollector &operator=(const DFCollector &) = delete;
 
 	DFCollector() {}
 	virtual ~DFCollector() {}
-	
+
 	virtual void add(AtomRef atom, double dx, double dy, double dz) = 0;
-	void add(AtomRef atom, mmcif::DPoint&& d)
+	void add(AtomRef atom, mmcif::DPoint &&d)
 	{
 		add(atom, d.mX, d.mY, d.mZ);
 	}
@@ -83,62 +89,84 @@ class Minimizer
   public:
 	typedef clipper::Xmap<float> XMap;
 
-	Minimizer(const Minimizer&) = delete;
-	Minimizer& operator=(const Minimizer&) = delete;
+	Minimizer(const Minimizer &) = delete;
+	Minimizer &operator=(const Minimizer &) = delete;
 
 	virtual ~Minimizer() {}
 
 	// factory method:
-	static Minimizer* create(const std::string& algorithm,
-		const mmcif::Polymer& poly, int first, int last, const mmcif::BondMap& bm,
-		const XMap& xMap, float mapWeight = 60, float plane5AtomsESD = 0.11);
+	static Minimizer *create(const mmcif::Polymer &poly, int first, int last,
+		const mmcif::BondMap &bm, const XMap &xMap, float mapWeight = 60, float plane5AtomsESD = 0.11);
+
+	static Minimizer *create(mmcif::Structure &structure, const std::vector<mmcif::Atom> &atoms,
+		const mmcif::BondMap &bm, const XMap &xMap, float mapWeight = 60, float plane5AtomsESD = 0.11)
+	{
+		return create(structure, atoms, bm, plane5AtomsESD, &xMap, mapWeight);
+	}
+
+	// factory method for minimizer without density:
+	static Minimizer *create(mmcif::Structure &structure, const std::vector<mmcif::Atom> &atoms,
+		const mmcif::BondMap &bm, float plane5AtomsESD = 0.11)
+	{
+		return create(structure, atoms, bm, plane5AtomsESD, nullptr, 0);
+	}
 
 	void printStats();
 
 	virtual double refine(bool storeAtoms) = 0;
 	double score();
-	virtual std::vector<std::pair<std::string,mmcif::Point>> getAtoms() const = 0;
+	virtual std::vector<std::pair<std::string, mmcif::Point>> getAtoms() const = 0;
 	virtual void storeAtomLocations() = 0;
 
   protected:
+	Minimizer(const mmcif::Structure &structure, const mmcif::BondMap &bm, float plane5AtomsESD);
 
-	Minimizer(const mmcif::Polymer& poly, int first, int last,
-		const mmcif::BondMap& bm, const XMap& xMap, float mapWeight,
-		float plane5AtomsESD);
+	static Minimizer *create(mmcif::Structure &structure, const std::vector<mmcif::Atom> &atoms,
+		const mmcif::BondMap &bm, float plane5AtomsESD, const XMap *xMap, float mapWeight);
 
-	double score(const AtomLocationProvider& loc);
+	virtual void addResidue(const mmcif::Residue &res);
+	virtual void addPolySection(const mmcif::Polymer &poly, int first, int last);
+	virtual void addDensityMap(const XMap &xMap, float mapWeight);
+	virtual void Finish();
 
-	void addLinkRestraints(const mmcif::Monomer& a, const mmcif::Monomer& b, const std::string& linkName)
+	double score(const AtomLocationProvider &loc);
+
+	void addLinkRestraints(const mmcif::Monomer &a, const mmcif::Monomer &b, const std::string &linkName)
 	{
-		addLinkRestraints(a, b, mmcif::Link::create(linkName));
+		addLinkRestraints(a, b, Link::create(linkName));
 	}
-	
-	void addLinkRestraints(const mmcif::Monomer& a, const mmcif::Monomer& b, const mmcif::Link& link);
 
-	template<typename R>
-	double rmsz(const AtomLocationProvider& atoms, const std::vector<R>& a) const
+	void addLinkRestraints(const mmcif::Monomer &a, const mmcif::Monomer &b, const Link &link);
+
+	template <typename R>
+	double rmsz(const AtomLocationProvider &atoms, const std::vector<R> &a) const
 	{
 		double result = 0;
-	
+
 		if (not a.empty())
 		{
 			double sumZ = accumulate(a.begin(), a.end(),
-				0.0, [&atoms](double sum, const R& r) { double z = r.f(atoms); return sum + z; });
-			
+				0.0, [&atoms](double sum, const R &r)
+				{ double z = r.f(atoms); return sum + z; });
+
 			result = sqrt(sumZ / a.size());
 		}
-		
+
 		return result;
 	}
 
-	AtomRef ref(const mmcif::Atom& atom);
+	AtomRef ref(const mmcif::Atom &atom);
 
-	bool mElectronScattering = false;	// TODO: use!
+	bool mElectronScattering = false; // TODO: use!
+
+	const mmcif::Structure &mStructure;
+	const mmcif::BondMap &mBonds;
+	float mPlane5ESD;
 
 	std::vector<mmcif::Atom> mAtoms, mReferencedAtoms;
 	std::vector<size_t> mRef2AtomIndex;
-	std::map<std::string,AtomRef> mRefIndex;
-	
+	std::map<std::string, AtomRef> mRefIndex;
+
 	std::vector<BondRestraint> mBondRestraints;
 	std::vector<AngleRestraint> mAngleRestraints;
 	std::vector<TorsionRestraint> mTorsionRestraints;
@@ -147,7 +175,8 @@ class Minimizer
 	std::vector<PlanarityRestraint> mPlanarityRestraints;
 	std::vector<NonBondedContactRestraint> mNonBondedContactRestraints;
 	std::unique_ptr<DensityRestraint> mDensityRestraint;
-	
-	std::vector<Restraint*> mRestraints;
+
+	std::vector<Restraint *> mRestraints;
 };
 
+} // namespace pdb_redo
\ No newline at end of file
